@@ -48,7 +48,7 @@ par(fig=c(0.18,0.82,0.18,0.82))
 par(mai=c(0.05,0.05,0.05,0.05)) 
 par(omi=c(0,0,0,0))
 par(cex.axis=0.5)
-plot(pcX$x[,1],pcX$x[,2],type="n",xlab="",ylab="",axes=F)
+plot(pcX$x[,1],pcX$x[,2],type="n",xlab="",ylab="", axes=FALSE)
 box()
 text(pcX$x[,1],pcX$x[,2],labels = 1:nitem,cex=0.7)
 abline(v=0,lty=2)
